@@ -22,8 +22,6 @@ import java.util.Random;
  * <p>Utility library that supplements the standard {@link Random} class.</p>
  * 
  * @since 3.3
- *
- * @version $Id: RandomUtils.java 1606051 2014-06-27 12:22:17Z ggregory $
  */
 public class RandomUtils {
 
@@ -49,6 +47,18 @@ public class RandomUtils {
         super();
     }
 
+    /**
+     * <p>
+     * Returns a random boolean value
+     * </p>
+     *
+     * @return the random boolean
+     * @since 3.5
+     */
+    public static boolean nextBoolean() {
+        return RANDOM.nextBoolean();
+    }
+    
     /**
      * <p>
      * Creates an array of random bytes.
@@ -92,6 +102,17 @@ public class RandomUtils {
         
         return startInclusive + RANDOM.nextInt(endExclusive - startInclusive);
     }
+
+    /**
+     * <p> Returns a random int within 0 - Integer.MAX_VALUE </p>
+     *
+     * @return the random integer
+     * @see #nextInt(int, int)
+     * @since 3.5
+     */
+    public static int nextInt() {
+        return nextInt(0, Integer.MAX_VALUE);
+    }
     
     /**
      * <p>
@@ -117,8 +138,18 @@ public class RandomUtils {
         }
 
         return (long) nextDouble(startInclusive, endExclusive);
-    }    
-    
+    }
+
+    /**
+     * <p> Returns a random long within 0 - Long.MAX_VALUE </p>
+     *
+     * @return the random long
+     * @see #nextLong(long, long)
+     * @since 3.5
+     */
+    public static long nextLong() {
+        return nextLong(0, Long.MAX_VALUE);
+    }
     
     /**
      * <p> 
@@ -138,14 +169,25 @@ public class RandomUtils {
         Validate.isTrue(endInclusive >= startInclusive,
                 "Start value must be smaller or equal to end value.");
         Validate.isTrue(startInclusive >= 0, "Both range values must be non-negative.");
-        
+
         if (startInclusive == endInclusive) {
             return startInclusive;
         }
         
         return startInclusive + ((endInclusive - startInclusive) * RANDOM.nextDouble());
     }
-    
+
+    /**
+     * <p> Returns a random double within 0 - Double.MAX_VALUE </p>
+     *
+     * @return the random double
+     * @see #nextDouble(double, double)
+     * @since 3.5
+     */
+    public static double nextDouble() {
+        return nextDouble(0, Double.MAX_VALUE);
+    }
+
     /**
      * <p>
      * Returns a random float within the specified range.
@@ -170,5 +212,16 @@ public class RandomUtils {
         }
         
         return startInclusive + ((endInclusive - startInclusive) * RANDOM.nextFloat());
-    }    
+    }
+
+    /**
+     * <p> Returns a random float within 0 - Float.MAX_VALUE </p>
+     *
+     * @return the random float
+     * @see #nextFloat()
+     * @since 3.5
+     */
+    public static float nextFloat() {
+        return nextFloat(0, Float.MAX_VALUE);
+    }
 }
