@@ -25,7 +25,6 @@ import org.apache.commons.lang3.math.NumberUtils;
  * 
  * @see Byte
  * @since 2.1
- * @version $Id: MutableByte.java 1669791 2015-03-28 15:22:59Z britter $
  */
 public class MutableByte extends Number implements Comparable<MutableByte>, Mutable<Number> {
 
@@ -120,6 +119,31 @@ public class MutableByte extends Number implements Comparable<MutableByte>, Muta
         value++;
     }
 
+    /**
+     * Increments this instance's value by 1; this method returns the value associated with the instance
+     * immediately prior to the increment operation. This method is not thread safe.
+     *
+     * @return the value associated with the instance before it was incremented
+     * @since 3.5
+     */
+    public byte getAndIncrement() {
+        byte last = value;
+        value++;
+        return last;
+    }
+
+    /**
+     * Increments this instance's value by 1; this method returns the value associated with the instance
+     * immediately after the increment operation. This method is not thread safe.
+     *
+     * @return the value associated with the instance after it is incremented
+     * @since 3.5
+     */
+    public byte incrementAndGet() {
+        value++;
+        return value;
+    }
+
     /**
      * Decrements the value.
      *
@@ -129,6 +153,31 @@ public class MutableByte extends Number implements Comparable<MutableByte>, Muta
         value--;
     }
 
+    /**
+     * Decrements this instance's value by 1; this method returns the value associated with the instance
+     * immediately prior to the decrement operation. This method is not thread safe.
+     *
+     * @return the value associated with the instance before it was decremented
+     * @since 3.5
+     */
+    public byte getAndDecrement() {
+        byte last = value;
+        value--;
+        return last;
+    }
+
+    /**
+     * Decrements this instance's value by 1; this method returns the value associated with the instance
+     * immediately after the decrement operation. This method is not thread safe.
+     *
+     * @return the value associated with the instance after it is decremented
+     * @since 3.5
+     */
+    public byte decrementAndGet() {
+        value--;
+        return value;
+    }
+
     //-----------------------------------------------------------------------
     /**
      * Adds a value to the value of this instance.
@@ -172,6 +221,62 @@ public class MutableByte extends Number implements Comparable<MutableByte>, Muta
         this.value -= operand.byteValue();
     }
 
+    /**
+     * Increments this instance's value by {@code operand}; this method returns the value associated with the instance
+     * immediately after the addition operation. This method is not thread safe.
+     *
+     * @param operand the quantity to add, not null
+     * @return the value associated with this instance after adding the operand
+     * @since 3.5
+     */
+    public byte addAndGet(final byte operand) {
+        this.value += operand;
+        return value;
+    }
+
+    /**
+     * Increments this instance's value by {@code operand}; this method returns the value associated with the instance
+     * immediately after the addition operation. This method is not thread safe.
+     *
+     * @param operand the quantity to add, not null
+     * @throws NullPointerException if {@code operand} is null
+     * @return the value associated with this instance after adding the operand
+     * @since 3.5
+     */
+    public byte addAndGet(final Number operand) {
+        this.value += operand.byteValue();
+        return value;
+    }
+
+    /**
+     * Increments this instance's value by {@code operand}; this method returns the value associated with the instance
+     * immediately prior to the addition operation. This method is not thread safe.
+     *
+     * @param operand the quantity to add, not null
+     * @return the value associated with this instance immediately before the operand was added
+     * @since 3.5
+     */
+    public byte getAndAdd(final byte operand) {
+        byte last = value;
+        this.value += operand;
+        return last;
+    }
+
+    /**
+     * Increments this instance's value by {@code operand}; this method returns the value associated with the instance
+     * immediately prior to the addition operation. This method is not thread safe.
+     *
+     * @param operand the quantity to add, not null
+     * @throws NullPointerException if {@code operand} is null
+     * @return the value associated with this instance immediately before the operand was added
+     * @since 3.5
+     */
+    public byte getAndAdd(final Number operand) {
+        byte last = value;
+        this.value += operand.byteValue();
+        return last;
+    }
+
     //-----------------------------------------------------------------------
     // shortValue relies on Number implementation
     /**
