@@ -42,7 +42,6 @@ import org.apache.commons.lang3.builder.Builder;
  * generics. </p>
  *
  * @since 3.0
- * @version $Id: TypeUtils.java 1535763 2013-10-25 15:25:22Z mbenson $
  */
 public class TypeUtils {
 
@@ -65,7 +64,7 @@ public class TypeUtils {
          * @param bounds to set
          * @return {@code this}
          */
-        public WildcardTypeBuilder withUpperBounds(Type... bounds) {
+        public WildcardTypeBuilder withUpperBounds(final Type... bounds) {
             this.upperBounds = bounds;
             return this;
         }
@@ -75,7 +74,7 @@ public class TypeUtils {
          * @param bounds to set
          * @return {@code this}
          */
-        public WildcardTypeBuilder withLowerBounds(Type... bounds) {
+        public WildcardTypeBuilder withLowerBounds(final Type... bounds) {
             this.lowerBounds = bounds;
             return this;
         }
@@ -100,7 +99,7 @@ public class TypeUtils {
          * Constructor
          * @param componentType of this array type
          */
-        private GenericArrayTypeImpl(Type componentType) {
+        private GenericArrayTypeImpl(final Type componentType) {
             this.componentType = componentType;
         }
 
@@ -124,7 +123,7 @@ public class TypeUtils {
          * {@inheritDoc}
          */
         @Override
-        public boolean equals(Object obj) {
+        public boolean equals(final Object obj) {
             return obj == this || obj instanceof GenericArrayType && TypeUtils.equals(this, (GenericArrayType) obj);
         }
 
@@ -154,10 +153,10 @@ public class TypeUtils {
          * @param useOwner owner type to use, if any
          * @param typeArguments formal type arguments
          */
-        private ParameterizedTypeImpl(Class<?> raw, Type useOwner, Type[] typeArguments) {
+        private ParameterizedTypeImpl(final Class<?> raw, final Type useOwner, final Type[] typeArguments) {
             this.raw = raw;
             this.useOwner = useOwner;
-            this.typeArguments = typeArguments;
+            this.typeArguments = typeArguments.clone();
         }
 
         /**
@@ -196,13 +195,14 @@ public class TypeUtils {
          * {@inheritDoc}
          */
         @Override
-        public boolean equals(Object obj) {
+        public boolean equals(final Object obj) {
             return obj == this || obj instanceof ParameterizedType && TypeUtils.equals(this, ((ParameterizedType) obj));
         }
 
         /**
          * {@inheritDoc}
          */
+        @SuppressWarnings( "deprecation" )  // ObjectUtils.hashCode(Object) has been deprecated in 3.2
         @Override
         public int hashCode() {
             int result = 71 << 4;
@@ -230,7 +230,7 @@ public class TypeUtils {
          * @param upperBounds of this type
          * @param lowerBounds of this type
          */
-        private WildcardTypeImpl(Type[] upperBounds, Type[] lowerBounds) {
+        private WildcardTypeImpl(final Type[] upperBounds, final Type[] lowerBounds) {
             this.upperBounds = ObjectUtils.defaultIfNull(upperBounds, EMPTY_BOUNDS);
             this.lowerBounds = ObjectUtils.defaultIfNull(lowerBounds, EMPTY_BOUNDS);
         }
@@ -263,7 +263,7 @@ public class TypeUtils {
          * {@inheritDoc}
          */
         @Override
-        public boolean equals(Object obj) {
+        public boolean equals(final Object obj) {
             return obj == this || obj instanceof WildcardType && TypeUtils.equals(this, (WildcardType) obj);
         }
 
@@ -464,6 +464,10 @@ public class TypeUtils {
             final Type toTypeArg = unrollVariableAssignments(var, toTypeVarAssigns);
             final Type fromTypeArg = unrollVariableAssignments(var, fromTypeVarAssigns);
 
+            if (toTypeArg == null && fromTypeArg instanceof Class) {
+                continue;
+            }
+
             // parameters must either be absent from the subject type, within
             // the bounds of the wildcard type, or be an exact match to the
             // parameters of the target type.
@@ -752,8 +756,8 @@ public class TypeUtils {
      * instance, this method will determine that both of the parameters for the
      * interface {@link Map} are {@link Object} for the subtype
      * {@link java.util.Properties Properties} even though the subtype does not
-     * directly implement the {@code Map} interface.<p> </p>This method
-     * returns {@code null} if {@code type} is not assignable to
+     * directly implement the {@code Map} interface.</p>
+     * <p>This method returns {@code null} if {@code type} is not assignable to
      * {@code toClass}. It returns an empty map if none of the classes or
      * interfaces in its inheritance hierarchy specify any type arguments.</p>
      * <p>A side effect of this method is that it also retrieves the type
@@ -1109,13 +1113,13 @@ public class TypeUtils {
      * <pre>&lt;K extends java.util.Collection&lt;String&gt; &amp;
      * java.util.List&lt;String&gt;&gt;</pre>
      *
+     * <p>
      * since {@code List} is a subinterface of {@code Collection},
      * this method will return the bounds as if the declaration had been:
+     * </p>
      *
      * <pre>&lt;K extends java.util.List&lt;String&gt;&gt;</pre>
      *
-     * </p>
-     *
      * @param bounds an array of types representing the upper bounds of either
      * {@link WildcardType} or {@link TypeVariable}, not {@code null}.
      * @return an array containing the values from {@code bounds} minus the
@@ -1423,7 +1427,7 @@ public class TypeUtils {
      * @return boolean
      * @since 3.2
      */
-    public static boolean containsTypeVariables(Type type) {
+    public static boolean containsTypeVariables(final Type type) {
         if (type instanceof TypeVariable<?>) {
             return true;
         }
@@ -1431,7 +1435,7 @@ public class TypeUtils {
             return ((Class<?>) type).getTypeParameters().length > 0;
         }
         if (type instanceof ParameterizedType) {
-            for (Type arg : ((ParameterizedType) type).getActualTypeArguments()) {
+            for (final Type arg : ((ParameterizedType) type).getActualTypeArguments()) {
                 if (containsTypeVariables(arg)) {
                     return true;
                 }
@@ -1439,7 +1443,7 @@ public class TypeUtils {
             return false;
         }
         if (type instanceof WildcardType) {
-            WildcardType wild = (WildcardType) type;
+            final WildcardType wild = (WildcardType) type;
             return containsTypeVariables(TypeUtils.getImplicitLowerBounds(wild)[0])
                 || containsTypeVariables(TypeUtils.getImplicitUpperBounds(wild)[0]);
         }
@@ -1499,7 +1503,7 @@ public class TypeUtils {
         }
         Validate.noNullElements(typeArguments, "null type argument at index %s");
         Validate.isTrue(raw.getTypeParameters().length == typeArguments.length,
-            "invalid number of type parameters specified: expected %s, got %s", raw.getTypeParameters().length,
+            "invalid number of type parameters specified: expected %d, got %d", raw.getTypeParameters().length,
             typeArguments.length);
 
         return new ParameterizedTypeImpl(raw, useOwner, typeArguments);
@@ -1527,10 +1531,10 @@ public class TypeUtils {
      * @param variables expected map keys
      * @return array of map values corresponding to specified keys
      */
-    private static Type[] extractTypeArgumentsFrom(Map<TypeVariable<?>, Type> mappings, TypeVariable<?>[] variables) {
+    private static Type[] extractTypeArgumentsFrom(final Map<TypeVariable<?>, Type> mappings, final TypeVariable<?>[] variables) {
         final Type[] result = new Type[variables.length];
         int index = 0;
-        for (TypeVariable<?> var : variables) {
+        for (final TypeVariable<?> var : variables) {
             Validate.isTrue(mappings.containsKey(var), "missing argument mapping for %s", toString(var));
             result[index++] = mappings.get(var);
         }
@@ -1566,7 +1570,8 @@ public class TypeUtils {
      * @return boolean
      * @since 3.2
      */
-    public static boolean equals(Type t1, Type t2) {
+    @SuppressWarnings( "deprecation" )  // ObjectUtils.equals(Object, Object) has been deprecated in 3.2
+    public static boolean equals(final Type t1, final Type t2) {
         if (ObjectUtils.equals(t1, t2)) {
             return true;
         }
@@ -1589,7 +1594,7 @@ public class TypeUtils {
      * @return boolean
      * @since 3.2
      */
-    private static boolean equals(ParameterizedType p, Type t) {
+    private static boolean equals(final ParameterizedType p, final Type t) {
         if (t instanceof ParameterizedType) {
             final ParameterizedType other = (ParameterizedType) t;
             if (equals(p.getRawType(), other.getRawType()) && equals(p.getOwnerType(), other.getOwnerType())) {
@@ -1606,7 +1611,7 @@ public class TypeUtils {
      * @return boolean
      * @since 3.2
      */
-    private static boolean equals(GenericArrayType a, Type t) {
+    private static boolean equals(final GenericArrayType a, final Type t) {
         return t instanceof GenericArrayType
             && equals(a.getGenericComponentType(), ((GenericArrayType) t).getGenericComponentType());
     }
@@ -1618,13 +1623,13 @@ public class TypeUtils {
      * @return boolean
      * @since 3.2
      */
-    private static boolean equals(WildcardType w, Type t) {
+    private static boolean equals(final WildcardType w, final Type t) {
         if (t instanceof WildcardType) {
             final WildcardType other = (WildcardType) t;
-            return equals(w.getLowerBounds(), other.getLowerBounds())
-                && equals(TypeUtils.getImplicitUpperBounds(w), TypeUtils.getImplicitUpperBounds(other));
+            return equals(getImplicitLowerBounds(w), getImplicitLowerBounds(other))
+                && equals(getImplicitUpperBounds(w), getImplicitUpperBounds(other));
         }
-        return true;
+        return false;
     }
 
     /**
@@ -1634,7 +1639,7 @@ public class TypeUtils {
      * @return boolean
      * @since 3.2
      */
-    private static boolean equals(Type[] t1, Type[] t2) {
+    private static boolean equals(final Type[] t1, final Type[] t2) {
         if (t1.length == t2.length) {
             for (int i = 0; i < t1.length; i++) {
                 if (!equals(t1[i], t2[i])) {
@@ -1653,7 +1658,7 @@ public class TypeUtils {
      * @return String
      * @since 3.2
      */
-    public static String toString(Type type) {
+    public static String toString(final Type type) {
         Validate.notNull(type);
         if (type instanceof Class<?>) {
             return classToString((Class<?>) type);
@@ -1680,7 +1685,7 @@ public class TypeUtils {
      * @return String
      * @since 3.2
      */
-    public static String toLongString(TypeVariable<?> var) {
+    public static String toLongString(final TypeVariable<?> var) {
         Validate.notNull(var, "var is null");
         final StringBuilder buf = new StringBuilder();
         final GenericDeclaration d = ((TypeVariable<?>) var).getGenericDeclaration();
@@ -1737,7 +1742,7 @@ public class TypeUtils {
      * @return String
      * @since 3.2
      */
-    private static String classToString(Class<?> c) {
+    private static String classToString(final Class<?> c) {
         final StringBuilder buf = new StringBuilder();
 
         if (c.getEnclosingClass() != null) {
@@ -1759,7 +1764,7 @@ public class TypeUtils {
      * @return String
      * @since 3.2
      */
-    private static String typeVariableToString(TypeVariable<?> v) {
+    private static String typeVariableToString(final TypeVariable<?> v) {
         final StringBuilder buf = new StringBuilder(v.getName());
         final Type[] bounds = v.getBounds();
         if (bounds.length > 0 && !(bounds.length == 1 && Object.class.equals(bounds[0]))) {
@@ -1775,7 +1780,7 @@ public class TypeUtils {
      * @return String
      * @since 3.2
      */
-    private static String parameterizedTypeToString(ParameterizedType p) {
+    private static String parameterizedTypeToString(final ParameterizedType p) {
         final StringBuilder buf = new StringBuilder();
 
         final Type useOwner = p.getOwnerType();
@@ -1802,13 +1807,13 @@ public class TypeUtils {
      * @return String
      * @since 3.2
      */
-    private static String wildcardTypeToString(WildcardType w) {
+    private static String wildcardTypeToString(final WildcardType w) {
         final StringBuilder buf = new StringBuilder().append('?');
         final Type[] lowerBounds = w.getLowerBounds();
         final Type[] upperBounds = w.getUpperBounds();
-        if (lowerBounds.length > 0) {
+        if (lowerBounds.length > 1 || lowerBounds.length == 1 && lowerBounds[0] != null) {
             appendAllTo(buf.append(" super "), " & ", lowerBounds);
-        } else if (!(upperBounds.length == 1 && Object.class.equals(upperBounds[0]))) {
+        } else if (upperBounds.length > 1 || upperBounds.length == 1 && !Object.class.equals(upperBounds[0])) {
             appendAllTo(buf.append(" extends "), " & ", upperBounds);
         }
         return buf.toString();
@@ -1820,7 +1825,7 @@ public class TypeUtils {
      * @return String
      * @since 3.2
      */
-    private static String genericArrayTypeToString(GenericArrayType g) {
+    private static String genericArrayTypeToString(final GenericArrayType g) {
         return String.format("%s[]", toString(g.getGenericComponentType()));
     }
 
@@ -1832,7 +1837,7 @@ public class TypeUtils {
      * @return {@code buf}
      * @since 3.2
      */
-    private static StringBuilder appendAllTo(StringBuilder buf, String sep, Type... types) {
+    private static StringBuilder appendAllTo(final StringBuilder buf, final String sep, final Type... types) {
         Validate.notEmpty(Validate.noNullElements(types));
         if (types.length > 0) {
             buf.append(toString(types[0]));
