@@ -83,7 +83,6 @@ import org.apache.commons.lang3.StringUtils;
  * </table>
  *
  * @since 2.2
- * @version $Id: StrTokenizer.java 1583482 2014-03-31 22:54:57Z niallp $
  */
 public class StrTokenizer implements ListIterator<String>, Cloneable {
 
@@ -647,7 +646,7 @@ public class StrTokenizer implements ListIterator<String>, Cloneable {
             
             // handle case where end of string is a delimiter
             if (pos >= count) {
-                addToken(tokenList, "");
+                addToken(tokenList, StringUtils.EMPTY);
             }
         }
         return tokenList;
@@ -699,14 +698,14 @@ public class StrTokenizer implements ListIterator<String>, Cloneable {
         
         // handle reaching end
         if (start >= len) {
-            addToken(tokenList, "");
+            addToken(tokenList, StringUtils.EMPTY);
             return -1;
         }
         
         // handle empty token
         final int delimLen = getDelimiterMatcher().isMatch(srcChars, start, start, len);
         if (delimLen > 0) {
-            addToken(tokenList, "");
+            addToken(tokenList, StringUtils.EMPTY);
             return start + delimLen;
         }
         
