@@ -23,6 +23,7 @@ import java.util.GregorianCalendar;
 import java.util.TimeZone;
 
 import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.Validate;
 
 /**
  * <p>Duration formatting utilities and constants. The following table describes the tokens 
@@ -45,7 +46,6 @@ import org.apache.commons.lang3.StringUtils;
  * A token character can be repeated to ensure that the field occupies a certain minimum
  * size. Values will be left-padded with 0 unless padding is disabled in the method invocation.
  * @since 2.1
- * @version $Id: DurationFormatUtils.java 1583482 2014-03-31 22:54:57Z niallp $
  */
 public class DurationFormatUtils {
 
@@ -61,37 +61,38 @@ public class DurationFormatUtils {
 
     /**
      * <p>Pattern used with <code>FastDateFormat</code> and <code>SimpleDateFormat</code>
-     * for the ISO8601 period format used in durations.</p>
+     * for the ISO 8601 period format used in durations.</p>
      * 
      * @see org.apache.commons.lang3.time.FastDateFormat
      * @see java.text.SimpleDateFormat
      */
-    public static final String ISO_EXTENDED_FORMAT_PATTERN = "'P'yyyy'Y'M'M'd'DT'H'H'm'M's.S'S'";
+    public static final String ISO_EXTENDED_FORMAT_PATTERN = "'P'yyyy'Y'M'M'd'DT'H'H'm'M's.SSS'S'";
 
     //-----------------------------------------------------------------------
     /**
      * <p>Formats the time gap as a string.</p>
      * 
-     * <p>The format used is ISO8601-like:
-     * <i>H</i>:<i>m</i>:<i>s</i>.<i>S</i>.</p>
-     * 
+     * <p>The format used is ISO 8601-like: {@code HH:mm:ss.SSS}.</p>
+     *
      * @param durationMillis  the duration to format
      * @return the formatted duration, not null
+     * @throws java.lang.IllegalArgumentException if durationMillis is negative
      */
     public static String formatDurationHMS(final long durationMillis) {
-        return formatDuration(durationMillis, "H:mm:ss.SSS");
+        return formatDuration(durationMillis, "HH:mm:ss.SSS");
     }
 
     /**
      * <p>Formats the time gap as a string.</p>
      * 
-     * <p>The format used is the ISO8601 period format.</p>
+     * <p>The format used is the ISO 8601 period format.</p>
      * 
      * <p>This method formats durations using the days and lower fields of the
      * ISO format pattern, such as P7D6TH5M4.321S.</p>
      * 
      * @param durationMillis  the duration to format
      * @return the formatted duration, not null
+     * @throws java.lang.IllegalArgumentException if durationMillis is negative
      */
     public static String formatDurationISO(final long durationMillis) {
         return formatDuration(durationMillis, ISO_EXTENDED_FORMAT_PATTERN, false);
@@ -106,6 +107,7 @@ public class DurationFormatUtils {
      * @param durationMillis  the duration to format
      * @param format  the way in which to format the duration, not null
      * @return the formatted duration, not null
+     * @throws java.lang.IllegalArgumentException if durationMillis is negative
      */
     public static String formatDuration(final long durationMillis, final String format) {
         return formatDuration(durationMillis, format, true);
@@ -122,8 +124,10 @@ public class DurationFormatUtils {
      * @param format  the way in which to format the duration, not null
      * @param padWithZeros  whether to pad the left hand side of numbers with 0's
      * @return the formatted duration, not null
+     * @throws java.lang.IllegalArgumentException if durationMillis is negative
      */
     public static String formatDuration(final long durationMillis, final String format, final boolean padWithZeros) {
+        Validate.inclusiveBetween(0, Long.MAX_VALUE, durationMillis, "durationMillis must not be negative");        
 
         final Token[] tokens = lexx(format);
 
@@ -154,7 +158,7 @@ public class DurationFormatUtils {
     }
 
     /**
-     * <p>Formats an elapsed time into a plurialization correct string.</p>
+     * <p>Formats an elapsed time into a pluralization correct string.</p>
      * 
      * <p>This method formats durations using the days and lower fields of the
      * format pattern. Months and larger are not used.</p>
@@ -163,29 +167,30 @@ public class DurationFormatUtils {
      * @param suppressLeadingZeroElements  suppresses leading 0 elements
      * @param suppressTrailingZeroElements  suppresses trailing 0 elements
      * @return the formatted text in days/hours/minutes/seconds, not null
+     * @throws java.lang.IllegalArgumentException if durationMillis is negative
      */
     public static String formatDurationWords(
         final long durationMillis,
         final boolean suppressLeadingZeroElements,
         final boolean suppressTrailingZeroElements) {
 
-        // This method is generally replacable by the format method, but 
+        // This method is generally replaceable by the format method, but
         // there are a series of tweaks and special cases that require 
         // trickery to replicate.
         String duration = formatDuration(durationMillis, "d' days 'H' hours 'm' minutes 's' seconds'");
         if (suppressLeadingZeroElements) {
             // this is a temporary marker on the front. Like ^ in regexp.
             duration = " " + duration;
-            String tmp = StringUtils.replaceOnce(duration, " 0 days", "");
+            String tmp = StringUtils.replaceOnce(duration, " 0 days", StringUtils.EMPTY);
             if (tmp.length() != duration.length()) {
                 duration = tmp;
-                tmp = StringUtils.replaceOnce(duration, " 0 hours", "");
+                tmp = StringUtils.replaceOnce(duration, " 0 hours", StringUtils.EMPTY);
                 if (tmp.length() != duration.length()) {
                     duration = tmp;
-                    tmp = StringUtils.replaceOnce(duration, " 0 minutes", "");
+                    tmp = StringUtils.replaceOnce(duration, " 0 minutes", StringUtils.EMPTY);
                     duration = tmp;
                     if (tmp.length() != duration.length()) {
-                        duration = StringUtils.replaceOnce(tmp, " 0 seconds", "");
+                        duration = StringUtils.replaceOnce(tmp, " 0 seconds", StringUtils.EMPTY);
                     }
                 }
             }
@@ -195,15 +200,15 @@ public class DurationFormatUtils {
             }
         }
         if (suppressTrailingZeroElements) {
-            String tmp = StringUtils.replaceOnce(duration, " 0 seconds", "");
+            String tmp = StringUtils.replaceOnce(duration, " 0 seconds", StringUtils.EMPTY);
             if (tmp.length() != duration.length()) {
                 duration = tmp;
-                tmp = StringUtils.replaceOnce(duration, " 0 minutes", "");
+                tmp = StringUtils.replaceOnce(duration, " 0 minutes", StringUtils.EMPTY);
                 if (tmp.length() != duration.length()) {
                     duration = tmp;
-                    tmp = StringUtils.replaceOnce(duration, " 0 hours", "");
+                    tmp = StringUtils.replaceOnce(duration, " 0 hours", StringUtils.EMPTY);
                     if (tmp.length() != duration.length()) {
-                        duration = StringUtils.replaceOnce(tmp, " 0 days", "");
+                        duration = StringUtils.replaceOnce(tmp, " 0 days", StringUtils.EMPTY);
                     }
                 }
             }
@@ -221,11 +226,12 @@ public class DurationFormatUtils {
     /**
      * <p>Formats the time gap as a string.</p>
      * 
-     * <p>The format used is the ISO8601 period format.</p>
+     * <p>The format used is the ISO 8601 period format.</p>
      * 
      * @param startMillis  the start of the duration to format
      * @param endMillis  the end of the duration to format
      * @return the formatted duration, not null
+     * @throws java.lang.IllegalArgumentException if startMillis is greater than endMillis
      */
     public static String formatPeriodISO(final long startMillis, final long endMillis) {
         return formatPeriod(startMillis, endMillis, ISO_EXTENDED_FORMAT_PATTERN, false, TimeZone.getDefault());
@@ -239,6 +245,7 @@ public class DurationFormatUtils {
      * @param endMillis  the end of the duration
      * @param format  the way in which to format the duration, not null
      * @return the formatted duration, not null
+     * @throws java.lang.IllegalArgumentException if startMillis is greater than endMillis
      */
     public static String formatPeriod(final long startMillis, final long endMillis, final String format) {
         return formatPeriod(startMillis, endMillis, format, true, TimeZone.getDefault());
@@ -266,9 +273,12 @@ public class DurationFormatUtils {
      * @param padWithZeros  whether to pad the left hand side of numbers with 0's
      * @param timezone  the millis are defined in
      * @return the formatted duration, not null
+     * @throws java.lang.IllegalArgumentException if startMillis is greater than endMillis
      */
     public static String formatPeriod(final long startMillis, final long endMillis, final String format, final boolean padWithZeros, 
             final TimeZone timezone) {
+        Validate.isTrue(startMillis <= endMillis, "startMillis must not be greater than endMillis");
+        
 
         // Used to optimise for differences under 28 days and 
         // called formatDuration(millis, format); however this did not work 
@@ -413,39 +423,37 @@ public class DurationFormatUtils {
      * @return the formatted string
      */
     static String format(final Token[] tokens, final long years, final long months, final long days, final long hours, final long minutes, final long seconds,
-            long milliseconds, final boolean padWithZeros) {
+            final long milliseconds, final boolean padWithZeros) {
         final StringBuilder buffer = new StringBuilder();
         boolean lastOutputSeconds = false;
-        final int sz = tokens.length;
-        for (int i = 0; i < sz; i++) {
-            final Token token = tokens[i];
+        for (final Token token : tokens) {
             final Object value = token.getValue();
             final int count = token.getCount();
             if (value instanceof StringBuilder) {
                 buffer.append(value.toString());
             } else {
-                if (value == y) {
+                if (value.equals(y)) {
                     buffer.append(paddedValue(years, padWithZeros, count));
                     lastOutputSeconds = false;
-                } else if (value == M) {
+                } else if (value.equals(M)) {
                     buffer.append(paddedValue(months, padWithZeros, count));
                     lastOutputSeconds = false;
-                } else if (value == d) {
+                } else if (value.equals(d)) {
                     buffer.append(paddedValue(days, padWithZeros, count));
                     lastOutputSeconds = false;
-                } else if (value == H) {
+                } else if (value.equals(H)) {
                     buffer.append(paddedValue(hours, padWithZeros, count));
                     lastOutputSeconds = false;
-                } else if (value == m) {
+                } else if (value.equals(m)) {
                     buffer.append(paddedValue(minutes, padWithZeros, count));
                     lastOutputSeconds = false;
-                } else if (value == s) {
+                } else if (value.equals(s)) {
                     buffer.append(paddedValue(seconds, padWithZeros, count));
                     lastOutputSeconds = true;
-                } else if (value == S) {
-                    if (lastOutputSeconds) { 
+                } else if (value.equals(S)) {
+                    if (lastOutputSeconds) {
                         // ensure at least 3 digits are displayed even if padding is not selected
-                        int width = padWithZeros ? Math.max(3, count) : 3;
+                        final int width = padWithZeros ? Math.max(3, count) : 3;
                         buffer.append(paddedValue(milliseconds, true, width));
                     } else {
                         buffer.append(paddedValue(milliseconds, padWithZeros, count));
@@ -457,7 +465,15 @@ public class DurationFormatUtils {
         return buffer.toString();
     }
 
-    // Helper method to simplify repetive code in format method above
+    /**
+     * <p>Converts a {@code long} to a {@code String} with optional
+     * zero padding.</p>
+     *
+     * @param value the value to convert
+     * @param padWithZeros whether to pad with zeroes
+     * @param count the size to pad to (ignored if {@code padWithZeros} is false)
+     * @return the string result
+     */
     private static String paddedValue(final long value, final boolean padWithZeros, final int count) {
         final String longString = Long.toString(value);
         return padWithZeros ? StringUtils.leftPad(longString, count, '0') : longString;
@@ -534,7 +550,7 @@ public class DurationFormatUtils {
             }
 
             if (value != null) {
-                if (previous != null && previous.getValue() == value) {
+                if (previous != null && previous.getValue().equals(value)) {
                     previous.increment();
                 } else {
                     final Token token = new Token(value);
@@ -564,9 +580,8 @@ public class DurationFormatUtils {
          * @return boolean <code>true</code> if contained
          */
         static boolean containsTokenWithValue(final Token[] tokens, final Object value) {
-            final int sz = tokens.length;
-            for (int i = 0; i < sz; i++) {
-                if (tokens[i].getValue() == value) {
+            for (final Token token : tokens) {
+                if (token.getValue() == value) {
                     return true;
                 }
             }
