@@ -30,6 +30,16 @@ import java.util.TimeZone;
  * <p>FastDateFormat is a fast and thread-safe version of
  * {@link java.text.SimpleDateFormat}.</p>
  *
+ * <p>To obtain an instance of FastDateFormat, use one of the static factory methods: 
+ * {@link #getInstance(String, TimeZone, Locale)}, {@link #getDateInstance(int, TimeZone, Locale)}, 
+ * {@link #getTimeInstance(int, TimeZone, Locale)}, or {@link #getDateTimeInstance(int, int, TimeZone, Locale)} 
+ * </p>
+ * 
+ * <p>Since FastDateFormat is thread safe, you can use a static member instance:</p>
+ * <code>
+ *   private static final FastDateFormat DATE_FORMATTER = FastDateFormat.getDateTimeInstance(FastDateFormat.LONG, FastDateFormat.SHORT);
+ * </code>
+ * 
  * <p>This class can be used as a direct replacement to
  * {@code SimpleDateFormat} in most formatting and parsing situations.
  * This class is especially useful in multi-threaded server environments.
@@ -39,7 +49,7 @@ import java.util.TimeZone;
  *
  * <p>All patterns are compatible with
  * SimpleDateFormat (except time zones and some year patterns - see below).</p>
- * 
+ *
  * <p>Since 3.2, FastDateFormat supports parsing as well as printing.</p>
  *
  * <p>Java 1.4 introduced a new pattern letter, {@code 'Z'}, to represent
@@ -47,7 +57,7 @@ import java.util.TimeZone;
  * This pattern letter can be used here (on all JDK versions).</p>
  *
  * <p>In addition, the pattern {@code 'ZZ'} has been made to represent
- * ISO8601 full format time zones (eg. {@code +08:00} or {@code -11:00}).
+ * ISO 8601 extended format time zones (eg. {@code +08:00} or {@code -11:00}).
  * This introduces a minor incompatibility with Java 1.4, but at a gain of
  * useful functionality.</p>
  *
@@ -58,7 +68,6 @@ import java.util.TimeZone;
  * versions. FastDateFormat implements the behavior of Java 7.</p>
  *
  * @since 2.0
- * @version $Id: FastDateFormat.java 1533798 2013-10-19 17:46:57Z tn $
  */
 public class FastDateFormat extends Format implements DateParser, DatePrinter {
     /**
@@ -94,7 +103,7 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
 
     private final FastDatePrinter printer;
     private final FastDateParser parser;
-    
+
     //-----------------------------------------------------------------------
     /**
      * <p>Gets a formatter instance using the default pattern in the
@@ -210,7 +219,7 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
     public static FastDateFormat getDateInstance(final int style, final TimeZone timeZone) {
         return cache.getDateInstance(style, timeZone, null);
     }
-    
+
     /**
      * <p>Gets a date formatter instance using the specified style, time
      * zone and locale.</p>
@@ -366,8 +375,23 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
      * @throws NullPointerException if pattern, timeZone, or locale is null.
      */
     protected FastDateFormat(final String pattern, final TimeZone timeZone, final Locale locale) {
+        this(pattern, timeZone, locale, null);
+    }
+
+    // Constructor
+    //-----------------------------------------------------------------------
+    /**
+     * <p>Constructs a new FastDateFormat.</p>
+     *
+     * @param pattern  {@link java.text.SimpleDateFormat} compatible pattern
+     * @param timeZone  non-null time zone to use
+     * @param locale  non-null locale to use
+     * @param centuryStart The start of the 100 year period to use as the "default century" for 2 digit year parsing.  If centuryStart is null, defaults to now - 80 years
+     * @throws NullPointerException if pattern, timeZone, or locale is null.
+     */
+    protected FastDateFormat(final String pattern, final TimeZone timeZone, final Locale locale, final Date centuryStart) {
         printer= new FastDatePrinter(pattern, timeZone, locale);
-        parser= new FastDateParser(pattern, timeZone, locale);
+        parser= new FastDateParser(pattern, timeZone, locale, centuryStart);
     }
 
     // Format methods
@@ -375,6 +399,7 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
     /**
      * <p>Formats a {@code Date}, {@code Calendar} or
      * {@code Long} (milliseconds) object.</p>
+     * This method is an implementation of {@link Format#format(Object, StringBuffer, FieldPosition)}
      *
      * @param obj  the object to format
      * @param toAppendTo  the buffer to append to
@@ -383,7 +408,7 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
      */
     @Override
     public StringBuffer format(final Object obj, final StringBuffer toAppendTo, final FieldPosition pos) {
-        return printer.format(obj, toAppendTo, pos);
+        return toAppendTo.append(printer.format(obj));
     }
 
     /**
@@ -428,7 +453,9 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
      * @param buf  the buffer to format into
      * @return the specified string buffer
      * @since 2.1
+     * @deprecated Use {{@link #format(long, Appendable)}.
      */
+    @Deprecated
     @Override
     public StringBuffer format(final long millis, final StringBuffer buf) {
         return printer.format(millis, buf);
@@ -441,7 +468,9 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
      * @param date  the date to format
      * @param buf  the buffer to format into
      * @return the specified string buffer
+     * @deprecated Use {{@link #format(Date, Appendable)}.
      */
+    @Deprecated
     @Override
     public StringBuffer format(final Date date, final StringBuffer buf) {
         return printer.format(date, buf);
@@ -454,16 +483,60 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
      * @param calendar  the calendar to format
      * @param buf  the buffer to format into
      * @return the specified string buffer
+     * @deprecated Use {{@link #format(Calendar, Appendable)}.
      */
+    @Deprecated
     @Override
     public StringBuffer format(final Calendar calendar, final StringBuffer buf) {
         return printer.format(calendar, buf);
     }
 
+    /**
+     * <p>Formats a millisecond {@code long} value into the
+     * supplied {@code StringBuffer}.</p>
+     *
+     * @param millis  the millisecond value to format
+     * @param buf  the buffer to format into
+     * @return the specified string buffer
+     * @since 3.5
+     */
+    @Override
+    public <B extends Appendable> B format(final long millis, final B buf) {
+        return printer.format(millis, buf);
+    }
+
+    /**
+     * <p>Formats a {@code Date} object into the
+     * supplied {@code StringBuffer} using a {@code GregorianCalendar}.</p>
+     *
+     * @param date  the date to format
+     * @param buf  the buffer to format into
+     * @return the specified string buffer
+     * @since 3.5
+     */
+    @Override
+    public <B extends Appendable> B format(final Date date, final B buf) {
+        return printer.format(date, buf);
+    }
+
+    /**
+     * <p>Formats a {@code Calendar} object into the
+     * supplied {@code StringBuffer}.</p>
+     *
+     * @param calendar  the calendar to format
+     * @param buf  the buffer to format into
+     * @return the specified string buffer
+     * @since 3.5
+    */
+    @Override
+    public <B extends Appendable> B format(final Calendar calendar, final B buf) {
+        return printer.format(calendar, buf);
+    }
+
     // Parsing
     //-----------------------------------------------------------------------
 
-    
+
     /* (non-Javadoc)
      * @see DateParser#parse(java.lang.String)
      */
@@ -477,7 +550,16 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
      */
     @Override
     public Date parse(final String source, final ParsePosition pos) {
-            return parser.parse(source, pos);
+        return parser.parse(source, pos);
+    }
+
+    /*
+     * (non-Javadoc)
+     * @see org.apache.commons.lang3.time.DateParser#parse(java.lang.String, java.text.ParsePosition, java.util.Calendar)
+     */
+    @Override
+    public boolean parse(final String source, final ParsePosition pos, final Calendar calendar) {
+        return parser.parse(source, pos, calendar);
     }
 
     /* (non-Javadoc)
@@ -573,18 +655,17 @@ public class FastDateFormat extends Format implements DateParser, DatePrinter {
         return "FastDateFormat[" + printer.getPattern() + "," + printer.getLocale() + "," + printer.getTimeZone().getID() + "]";
     }
 
-
     /**
      * <p>Performs the formatting by applying the rules to the
      * specified calendar.</p>
      *
-     * @param calendar  the calendar to format
+     * @param calendar the calendar to format
      * @param buf  the buffer to format into
      * @return the specified string buffer
+     * @deprecated Use {@link #format(Calendar, Appendable)}
      */
+    @Deprecated
     protected StringBuffer applyRules(final Calendar calendar, final StringBuffer buf) {
         return printer.applyRules(calendar, buf);
     }
-
-
 }
