@@ -32,37 +32,40 @@ import static org.junit.Assert.fail;
 import java.lang.reflect.Method;
 import java.lang.reflect.Type;
 import java.util.Arrays;
+import java.util.Date;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
 import org.apache.commons.lang3.ArrayUtils;
+import org.apache.commons.lang3.ClassUtils;
+import org.apache.commons.lang3.ClassUtils.Interfaces;
 import org.apache.commons.lang3.math.NumberUtils;
 import org.apache.commons.lang3.mutable.Mutable;
 import org.apache.commons.lang3.mutable.MutableObject;
-import org.apache.commons.lang3.ClassUtils.Interfaces;
 import org.apache.commons.lang3.reflect.testbed.Annotated;
 import org.apache.commons.lang3.reflect.testbed.GenericConsumer;
 import org.apache.commons.lang3.reflect.testbed.GenericParent;
 import org.apache.commons.lang3.reflect.testbed.StringParameterizedChild;
+import org.apache.commons.lang3.tuple.ImmutablePair;
+import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
 /**
  * Unit tests MethodUtils
- * @version $Id: MethodUtilsTest.java 1630268 2014-10-09 02:22:34Z ggregory $
  */
 public class MethodUtilsTest {
-  
+
     private static interface PrivateInterface {}
-    
+
     static class TestBeanWithInterfaces implements PrivateInterface {
         public String foo() {
             return "foo()";
         }
     }
-    
+
     public static class TestBean {
 
         public static String bar() {
@@ -88,15 +91,53 @@ public class MethodUtilsTest {
         public static String bar(final Object o) {
             return "bar(Object)";
         }
-        
+
+        public static String bar(final String... s) {
+            return "bar(String...)";
+        }
+
+        public static String bar(final Integer i, final String... s) {
+            return "bar(int, String...)";
+        }
+
         public static void oneParameterStatic(final String s) {
             // empty
         }
-
+        
         @SuppressWarnings("unused")
         private void privateStuff() {
         }
 
+        @SuppressWarnings("unused")
+        private String privateStringStuff() {
+        	return "privateStringStuff()";
+        }
+        
+        @SuppressWarnings("unused")
+        private String privateStringStuff(final int i) {
+        	return "privateStringStuff(int)";
+        }
+        
+        @SuppressWarnings("unused")
+        private String privateStringStuff(final Integer i) {
+        	return "privateStringStuff(Integer)";
+        }
+        
+        @SuppressWarnings("unused")
+        private String privateStringStuff(final double d) {
+        	return "privateStringStuff(double)";
+        }
+        
+        @SuppressWarnings("unused")
+        private String privateStringStuff(final String s) {
+        	return "privateStringStuff(String)";
+        }
+        
+        @SuppressWarnings("unused")
+        private String privateStringStuff(final Object s) {
+        	return "privateStringStuff(Object)";
+        }
+
 
         public String foo() {
             return "foo()";
@@ -121,10 +162,79 @@ public class MethodUtilsTest {
         public String foo(final Object o) {
             return "foo(Object)";
         }
-        
+
+        public String foo(final String... s) {
+            return "foo(String...)";
+        }
+
+        public String foo(final Integer i, final String... s) {
+            return "foo(int, String...)";
+        }
+
         public void oneParameter(final String s) {
             // empty
         }
+
+        public String foo(final Object... s) {
+            return "foo(Object...)";
+        }
+
+        public int[] unboxing(int... values) {
+            return values;
+        }
+
+        // This method is overloaded for the wrapper class for every primitive type, plus the common supertypes
+        // Number and Object. This is an acid test since it easily leads to ambiguous methods.
+        public static String varOverload(Byte... args) { return "Byte..."; }
+        public static String varOverload(Character... args) { return "Character..."; }
+        public static String varOverload(Short... args) { return "Short..."; }
+        public static String varOverload(Boolean... args) { return "Boolean..."; }
+        public static String varOverload(Float... args) { return "Float..."; }
+        public static String varOverload(Double... args) { return "Double..."; }
+        public static String varOverload(Integer... args) { return "Integer..."; }
+        public static String varOverload(Long... args) { return "Long..."; }
+        public static String varOverload(Number... args) { return "Number..."; }
+        public static String varOverload(Object... args) { return "Object..."; }
+        public static String varOverload(String... args) { return "String..."; }
+
+        // This method is overloaded for the wrapper class for every numeric primitive type, plus the common
+        // supertype Number
+        public static String numOverload(Byte... args) { return "Byte..."; }
+        public static String numOverload(Short... args) { return "Short..."; }
+        public static String numOverload(Float... args) { return "Float..."; }
+        public static String numOverload(Double... args) { return "Double..."; }
+        public static String numOverload(Integer... args) { return "Integer..."; }
+        public static String numOverload(Long... args) { return "Long..."; }
+        public static String numOverload(Number... args) { return "Number..."; }
+
+        // These varOverloadEcho and varOverloadEchoStatic methods are designed to verify that
+        // not only is the correct overloaded variant invoked, but that the varags arguments
+        // are also delivered correctly to the method.
+        public ImmutablePair<String, Object[]> varOverloadEcho(String... args) {
+          return new ImmutablePair<String, Object[]>("String...", args);
+        }
+        public ImmutablePair<String, Object[]> varOverloadEcho(Number... args) {
+          return new ImmutablePair<String, Object[]>("Number...", args);
+        }
+
+        public static ImmutablePair<String, Object[]> varOverloadEchoStatic(String... args) {
+          return new ImmutablePair<String, Object[]>("String...", args);
+        }
+        public static ImmutablePair<String, Object[]> varOverloadEchoStatic(Number... args) {
+          return new ImmutablePair<String, Object[]>("Number...", args);
+        }
+
+        static void verify(ImmutablePair<String, Object[]> a, ImmutablePair<String, Object[]> b) {
+          assertEquals(a.getLeft(), b.getLeft());
+          assertArrayEquals(a.getRight(), b.getRight());
+        }
+
+        static void verify(ImmutablePair<String, Object[]> a, Object _b) {
+          @SuppressWarnings("unchecked")
+          final ImmutablePair<String, Object[]> b = (ImmutablePair<String, Object[]>) _b;
+          verify(a, b);
+        }
+
     }
 
     private static class TestMutable implements Mutable<Object> {
@@ -152,6 +262,81 @@ public class MethodUtilsTest {
         assertNotNull(MethodUtils.class.newInstance());
     }
 
+    @Test
+    public void verifyJavaVarargsOverloadingResolution() throws Exception {
+        // This code is not a test of MethodUtils.
+        // Rather it makes explicit the behavior of the Java specification for
+        // various cases of overload resolution.
+        assertEquals("Byte...", TestBean.varOverload((byte) 1, (byte) 2));
+        assertEquals("Short...", TestBean.varOverload((short) 1, (short) 2));
+        assertEquals("Integer...", TestBean.varOverload(1, 2));
+        assertEquals("Long...", TestBean.varOverload(1L, 2L));
+        assertEquals("Float...", TestBean.varOverload(1f, 2f));
+        assertEquals("Double...", TestBean.varOverload(1d, 2d));
+        assertEquals("Character...", TestBean.varOverload('a', 'b'));
+        assertEquals("String...", TestBean.varOverload("a", "b"));
+        assertEquals("Boolean...", TestBean.varOverload(true, false));
+
+        assertEquals("Object...", TestBean.varOverload(1, "s"));
+        assertEquals("Object...", TestBean.varOverload(1, true));
+        assertEquals("Object...", TestBean.varOverload(1.1, true));
+        assertEquals("Object...", TestBean.varOverload('c', true));
+        assertEquals("Number...", TestBean.varOverload(1, 1.1));
+        assertEquals("Number...", TestBean.varOverload(1, 1L));
+        assertEquals("Number...", TestBean.varOverload(1d, 1f));
+        assertEquals("Number...", TestBean.varOverload((short) 1, (byte) 1));
+        assertEquals("Object...", TestBean.varOverload(1, 'c'));
+        assertEquals("Object...", TestBean.varOverload('c', "s"));
+    }
+
+    @Test
+    public void testInvokeJavaVarargsOverloadingResolution() throws Exception {
+        assertEquals("Byte...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", (byte) 1, (byte) 2));
+        assertEquals("Short...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", (short) 1, (short) 2));
+        assertEquals("Integer...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1, 2));
+        assertEquals("Long...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1L, 2L));
+        assertEquals("Float...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1f, 2f));
+        assertEquals("Double...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1d, 2d));
+        assertEquals("Character...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 'a', 'b'));
+        assertEquals("String...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", "a", "b"));
+        assertEquals("Boolean...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", true, false));
+
+        assertEquals("Object...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1, "s"));
+        assertEquals("Object...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1, true));
+        assertEquals("Object...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1.1, true));
+        assertEquals("Object...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 'c', true));
+        assertEquals("Number...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1, 1.1));
+        assertEquals("Number...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1, 1L));
+        assertEquals("Number...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1d, 1f));
+        assertEquals("Number...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", (short) 1, (byte) 1));
+        assertEquals("Object...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 1, 'c'));
+        assertEquals("Object...", MethodUtils.invokeStaticMethod(TestBean.class,
+                "varOverload", 'c', "s"));
+
+        assertEquals("Object...", MethodUtils.invokeStaticMethod(TestBean.class, "varOverload",
+                (Object[]) ArrayUtils.EMPTY_CLASS_ARRAY));
+        assertEquals("Number...", MethodUtils.invokeStaticMethod(TestBean.class, "numOverload",
+                (Object[]) ArrayUtils.EMPTY_CLASS_ARRAY));
+    }
+
     @Test
     public void testInvokeMethod() throws Exception {
         assertEquals("foo()", MethodUtils.invokeMethod(testBean, "foo",
@@ -159,7 +344,7 @@ public class MethodUtilsTest {
         assertEquals("foo()", MethodUtils.invokeMethod(testBean, "foo"));
         assertEquals("foo()", MethodUtils.invokeMethod(testBean, "foo",
                 (Object[]) null));
-        assertEquals("foo()", MethodUtils.invokeMethod(testBean, "foo", 
+        assertEquals("foo()", MethodUtils.invokeMethod(testBean, "foo",
                 (Object[]) null, (Class<?>[]) null));
         assertEquals("foo(String)", MethodUtils.invokeMethod(testBean, "foo",
                 ""));
@@ -175,6 +360,21 @@ public class MethodUtilsTest {
                 NumberUtils.LONG_ONE));
         assertEquals("foo(double)", MethodUtils.invokeMethod(testBean, "foo",
                 NumberUtils.DOUBLE_ONE));
+        assertEquals("foo(String...)", MethodUtils.invokeMethod(testBean, "foo",
+                "a", "b", "c"));
+        assertEquals("foo(String...)", MethodUtils.invokeMethod(testBean, "foo",
+                "a", "b", "c"));
+        assertEquals("foo(int, String...)", MethodUtils.invokeMethod(testBean, "foo",
+                5, "a", "b", "c"));
+
+        TestBean.verify(new ImmutablePair<String, Object[]>("String...", new String[]{"x", "y"}),
+                        MethodUtils.invokeMethod(testBean, "varOverloadEcho", "x", "y"));
+        TestBean.verify(new ImmutablePair<String, Object[]>("Number...", new Number[]{17, 23, 42}),
+                        MethodUtils.invokeMethod(testBean, "varOverloadEcho", 17, 23, 42));
+        TestBean.verify(new ImmutablePair<String, Object[]>("String...", new String[]{"x", "y"}),
+                        MethodUtils.invokeMethod(testBean, "varOverloadEcho", "x", "y"));
+        TestBean.verify(new ImmutablePair<String, Object[]>("Number...", new Number[]{17, 23, 42}),
+                        MethodUtils.invokeMethod(testBean, "varOverloadEcho", 17, 23, 42));
     }
 
     @Test
@@ -184,7 +384,7 @@ public class MethodUtilsTest {
         assertEquals("foo()", MethodUtils.invokeExactMethod(testBean, "foo"));
         assertEquals("foo()", MethodUtils.invokeExactMethod(testBean, "foo",
                 (Object[]) null));
-        assertEquals("foo()", MethodUtils.invokeExactMethod(testBean, "foo", 
+        assertEquals("foo()", MethodUtils.invokeExactMethod(testBean, "foo",
                 (Object[]) null, (Class<?>[]) null));
         assertEquals("foo(String)", MethodUtils.invokeExactMethod(testBean,
                 "foo", ""));
@@ -237,7 +437,20 @@ public class MethodUtilsTest {
                 TestBean.class, "bar", NumberUtils.LONG_ONE));
         assertEquals("bar(double)", MethodUtils.invokeStaticMethod(
                 TestBean.class, "bar", NumberUtils.DOUBLE_ONE));
-        
+        assertEquals("bar(String...)", MethodUtils.invokeStaticMethod(
+                TestBean.class, "bar", "a", "b"));
+        assertEquals("bar(int, String...)", MethodUtils.invokeStaticMethod(
+                TestBean.class, "bar", NumberUtils.INTEGER_ONE, "a", "b"));
+
+        TestBean.verify(new ImmutablePair<String, Object[]>("String...", new String[]{"x", "y"}),
+                        MethodUtils.invokeStaticMethod(TestBean.class, "varOverloadEchoStatic", "x", "y"));
+        TestBean.verify(new ImmutablePair<String, Object[]>("Number...", new Number[]{17, 23, 42}),
+                        MethodUtils.invokeStaticMethod(TestBean.class, "varOverloadEchoStatic", 17, 23, 42));
+        TestBean.verify(new ImmutablePair<String, Object[]>("String...", new String[]{"x", "y"}),
+                        MethodUtils.invokeStaticMethod(TestBean.class, "varOverloadEchoStatic", "x", "y"));
+        TestBean.verify(new ImmutablePair<String, Object[]>("Number...", new Number[]{17, 23, 42}),
+                        MethodUtils.invokeStaticMethod(TestBean.class, "varOverloadEchoStatic", 17, 23, 42));
+
         try {
             MethodUtils.invokeStaticMethod(TestBean.class, "does_not_exist");
             fail("should throw NoSuchMethodException");
@@ -293,7 +506,7 @@ public class MethodUtilsTest {
             assertSame(Mutable.class, accessibleMethod.getDeclaringClass());
         }
     }
-    
+
     @Test
     public void testGetAccessibleMethodPrivateInterface() throws Exception {
         final Method expected = TestBeanWithInterfaces.class.getMethod("foo");
@@ -326,7 +539,7 @@ public class MethodUtilsTest {
                 MutableObject.class, "getValue", ArrayUtils.EMPTY_CLASS_ARRAY)
                 .getDeclaringClass());
     }
-    
+
     @Test
    public void testGetAccessibleMethodInaccessible() throws Exception {
         final Method expected = TestBean.class.getDeclaredMethod("privateStuff");
@@ -376,6 +589,10 @@ public class MethodUtilsTest {
                 singletonArray(Double.TYPE), singletonArray(Double.TYPE));
         expectMatchingAccessibleMethodParameterTypes(TestBean.class, "foo",
                 singletonArray(Double.TYPE), singletonArray(Double.TYPE));
+        expectMatchingAccessibleMethodParameterTypes(TestBean.class, "foo",
+                new Class[] {String.class, String.class}, new Class[] {String[].class});
+        expectMatchingAccessibleMethodParameterTypes(TestBean.class, "foo",
+                new Class[] {Integer.TYPE, String.class, String.class}, new Class[] {Integer.class, String[].class});
         expectMatchingAccessibleMethodParameterTypes(InheritanceBean.class, "testOne",
                 singletonArray(ParentObject.class), singletonArray(ParentObject.class));
         expectMatchingAccessibleMethodParameterTypes(InheritanceBean.class, "testOne",
@@ -486,11 +703,13 @@ public class MethodUtilsTest {
     public void testGetMethodsListWithAnnotationIllegalArgumentException3() {
         MethodUtils.getMethodsListWithAnnotation(null, null);
     }
-    
+
     private void expectMatchingAccessibleMethodParameterTypes(final Class<?> cls,
             final String methodName, final Class<?>[] requestTypes, final Class<?>[] actualTypes) {
         final Method m = MethodUtils.getMatchingAccessibleMethod(cls, methodName,
                 requestTypes);
+        assertNotNull("could not find any matches for " + methodName
+                + " (" + (requestTypes == null ? null : toString(requestTypes)) + ")", m);
         assertTrue(toString(m.getParameterTypes()) + " not equals "
                 + toString(actualTypes), Arrays.equals(actualTypes, m
                 .getParameterTypes()));
@@ -517,8 +736,8 @@ public class MethodUtilsTest {
         public void testTwo(final GrandParentObject obj) {}
         public void testTwo(final ChildInterface obj) {}
     }
-    
-    interface ChildInterface {}    
+
+    interface ChildInterface {}
     public static class GrandParentObject {}
     public static class ParentObject extends GrandParentObject {}
     public static class ChildObject extends ParentObject implements ChildInterface {}
@@ -534,4 +753,40 @@ public class MethodUtilsTest {
             this.parameterTypes = parameterTypes;
         }
     }
+
+    @Test
+    public void testVarArgsUnboxing() throws Exception {
+        TestBean testBean = new TestBean();
+        int[] actual = (int[])MethodUtils.invokeMethod(testBean, "unboxing", Integer.valueOf(1), Integer.valueOf(2));
+        Assert.assertArrayEquals(new int[]{1, 2}, actual);
+    }
+    
+    @Test
+    public void testInvokeMethodForceAccessNoArgs() throws Exception {
+        Method privateStringStuffMethod = MethodUtils.getMatchingMethod(TestBean.class, "privateStringStuff");
+        Assert.assertFalse(privateStringStuffMethod.isAccessible());
+        Assert.assertEquals("privateStringStuff()", MethodUtils.invokeMethod(testBean, true, "privateStringStuff"));
+        Assert.assertFalse(privateStringStuffMethod.isAccessible());
+    }
+    
+    @Test
+    public void testInvokeMethodForceAccessWithArgs() throws Exception {
+        Assert.assertEquals("privateStringStuff(Integer)", MethodUtils.invokeMethod(testBean, true, "privateStringStuff", 5));
+        Assert.assertEquals("privateStringStuff(double)", MethodUtils.invokeMethod(testBean, true, "privateStringStuff", 5.0d));
+        Assert.assertEquals("privateStringStuff(String)", MethodUtils.invokeMethod(testBean, true, "privateStringStuff", "Hi There"));
+        Assert.assertEquals("privateStringStuff(Object)", MethodUtils.invokeMethod(testBean, true, "privateStringStuff", new Date()));
+    }
+    
+    @Test
+    public void testDistance() throws Exception {
+        Method distanceMethod = MethodUtils.getMatchingMethod(MethodUtils.class, "distance", Class[].class, Class[].class);
+        distanceMethod.setAccessible(true);
+        
+        Assert.assertEquals(-1, distanceMethod.invoke(null, new Class[]{String.class}, new Class[]{Date.class}));
+        Assert.assertEquals(0, distanceMethod.invoke(null, new Class[]{Date.class}, new Class[]{Date.class}));
+        Assert.assertEquals(1, distanceMethod.invoke(null, new Class[]{Integer.class}, new Class[]{ClassUtils.wrapperToPrimitive(Integer.class)}));
+        Assert.assertEquals(2, distanceMethod.invoke(null, new Class[]{Integer.class}, new Class[]{Object.class}));
+        
+        distanceMethod.setAccessible(false);
+    }
 }
