@@ -19,8 +19,10 @@ package org.apache.commons.lang3.time;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
+
 import java.io.Serializable;
 import java.text.ParseException;
+import java.text.ParsePosition;
 import java.text.SimpleDateFormat;
 import java.util.Calendar;
 import java.util.Date;
@@ -30,20 +32,19 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.TimeZone;
 
-import org.junit.Assert;
-
+import org.apache.commons.lang3.LocaleUtils;
 import org.apache.commons.lang3.SerializationUtils;
+import org.junit.Assert;
 import org.junit.Test;
 
 /**
  * Unit tests {@link org.apache.commons.lang3.time.FastDateParser}.
  *
- * @version $Id: FastDateParserTest.java 1552661 2013-12-20 13:36:30Z britter $
  * @since 3.2
  */
 public class FastDateParserTest {
-    private static final String SHORT_FORMAT_NOERA = "y/M/d/h/a/m/E/Z";
-    private static final String LONG_FORMAT_NOERA = "yyyy/MMMM/dddd/hhhh/mmmm/aaaa/EEEE/ZZZZ";
+    private static final String SHORT_FORMAT_NOERA = "y/M/d/h/a/m/s/E";
+    private static final String LONG_FORMAT_NOERA = "yyyy/MMMM/dddd/hhhh/mmmm/ss/aaaa/EEEE";
     private static final String SHORT_FORMAT = "G/" + SHORT_FORMAT_NOERA;
     private static final String LONG_FORMAT = "GGGG/" + LONG_FORMAT_NOERA;
 
@@ -56,6 +57,7 @@ public class FastDateParserTest {
     private static final TimeZone REYKJAVIK = TimeZone.getTimeZone("Atlantic/Reykjavik");
     private static final TimeZone NEW_YORK = TimeZone.getTimeZone("America/New_York");
     private static final TimeZone GMT = TimeZone.getTimeZone("GMT");
+    private static final TimeZone INDIA = TimeZone.getTimeZone("Asia/Calcutta");
 
     private static final Locale SWEDEN = new Locale("sv", "SE");
 
@@ -77,9 +79,15 @@ public class FastDateParserTest {
 
     /**
      * Override this method in derived tests to change the construction of instances
+     *
+     * @param format the format string to use
+     * @param timeZone the time zone to use
+     * @param locale the locale to use
+     *
+     * @return the DateParser instance to use for testing
      */
     protected DateParser getInstance(final String format, final TimeZone timeZone, final Locale locale) {
-        return new FastDateParser(format, timeZone, locale);
+        return new FastDateParser(format, timeZone, locale, null);
     }
 
     @Test
@@ -110,7 +118,7 @@ public class FastDateParserTest {
     public void testParseZone() throws ParseException {
         final Calendar cal= Calendar.getInstance(NEW_YORK, Locale.US);
         cal.clear();
-        cal.set(2003, 6, 10, 16, 33, 20);
+        cal.set(2003, Calendar.JULY, 10, 16, 33, 20);
 
         final DateParser fdf = getInstance(yMdHmsSZ, NEW_YORK, Locale.US);
 
@@ -120,12 +128,12 @@ public class FastDateParserTest {
         assertEquals(cal.getTime(), fdf.parse("2003-07-10T16:33:20.000 EDT"));
 
         cal.setTimeZone(TimeZone.getTimeZone("GMT-3"));
-        cal.set(2003, 1, 10, 9, 0, 0);
+        cal.set(2003, Calendar.FEBRUARY, 10, 9, 0, 0);
 
         assertEquals(cal.getTime(), fdf.parse("2003-02-10T09:00:00.000 -0300"));
 
         cal.setTimeZone(TimeZone.getTimeZone("GMT+5"));
-        cal.set(2003, 1, 10, 15, 5, 6);
+        cal.set(2003, Calendar.FEBRUARY, 10, 15, 5, 6);
 
         assertEquals(cal.getTime(), fdf.parse("2003-02-10T15:05:06.000 +0500"));
     }
@@ -134,7 +142,7 @@ public class FastDateParserTest {
     public void testParseLongShort() throws ParseException {
         final Calendar cal= Calendar.getInstance(NEW_YORK, Locale.US);
         cal.clear();
-        cal.set(2003, 1, 10, 15, 33, 20);
+        cal.set(2003, Calendar.FEBRUARY, 10, 15, 33, 20);
         cal.set(Calendar.MILLISECOND, 989);
         cal.setTimeZone(NEW_YORK);
 
@@ -163,72 +171,114 @@ public class FastDateParserTest {
         final DateParser k = getInstance("yyyy-MM-dd kk:mm:ss", NEW_YORK, Locale.US);
         final DateParser H = getInstance("yyyy-MM-dd HH:mm:ss", NEW_YORK, Locale.US);
 
-        cal.set(2010, 7, 1, 0, 33, 20);
+        cal.set(2010, Calendar.AUGUST, 1, 0, 33, 20);
         assertEquals(cal.getTime(), h.parse("2010-08-01 12 AM 33:20"));
         assertEquals(cal.getTime(), K.parse("2010-08-01 0 AM 33:20"));
         assertEquals(cal.getTime(), k.parse("2010-08-01 00:33:20"));
         assertEquals(cal.getTime(), H.parse("2010-08-01 00:33:20"));
 
-        cal.set(2010, 7, 1, 3, 33, 20);
+        cal.set(2010, Calendar.AUGUST, 1, 3, 33, 20);
         assertEquals(cal.getTime(), h.parse("2010-08-01 3 AM 33:20"));
         assertEquals(cal.getTime(), K.parse("2010-08-01 3 AM 33:20"));
         assertEquals(cal.getTime(), k.parse("2010-08-01 03:33:20"));
         assertEquals(cal.getTime(), H.parse("2010-08-01 03:33:20"));
 
-        cal.set(2010, 7, 1, 15, 33, 20);
+        cal.set(2010, Calendar.AUGUST, 1, 15, 33, 20);
         assertEquals(cal.getTime(), h.parse("2010-08-01 3 PM 33:20"));
         assertEquals(cal.getTime(), K.parse("2010-08-01 3 PM 33:20"));
         assertEquals(cal.getTime(), k.parse("2010-08-01 15:33:20"));
         assertEquals(cal.getTime(), H.parse("2010-08-01 15:33:20"));
 
-        cal.set(2010, 7, 1, 12, 33, 20);
+        cal.set(2010, Calendar.AUGUST, 1, 12, 33, 20);
         assertEquals(cal.getTime(), h.parse("2010-08-01 12 PM 33:20"));
         assertEquals(cal.getTime(), K.parse("2010-08-01 0 PM 33:20"));
         assertEquals(cal.getTime(), k.parse("2010-08-01 12:33:20"));
         assertEquals(cal.getTime(), H.parse("2010-08-01 12:33:20"));
     }
 
+    private Calendar getEraStart(int year, final TimeZone zone, final Locale locale) {
+        final Calendar cal = Calendar.getInstance(zone, locale);
+        cal.clear();
+
+        // http://docs.oracle.com/javase/6/docs/technotes/guides/intl/calendar.doc.html
+        if (locale.equals(FastDateParser.JAPANESE_IMPERIAL)) {
+            if(year < 1868) {
+                cal.set(Calendar.ERA, 0);
+                cal.set(Calendar.YEAR, 1868-year);
+            }
+        }
+        else {
+            if (year < 0) {
+                cal.set(Calendar.ERA, GregorianCalendar.BC);
+                year= -year;
+            }
+            cal.set(Calendar.YEAR, year/100 * 100);
+        }
+        return cal;
+    }
+
+    private void validateSdfFormatFdpParseEquality(final String format, final Locale locale, final TimeZone tz, final DateParser fdp, final Date in, final int year, final Date cs) throws ParseException {
+        final SimpleDateFormat sdf = new SimpleDateFormat(format, locale);
+        sdf.setTimeZone(tz);
+        if (format.equals(SHORT_FORMAT)) {
+            sdf.set2DigitYearStart( cs );
+        }
+        final String fmt = sdf.format(in);
+        try {
+            final Date out = fdp.parse(fmt);
+            assertEquals(locale.toString()+" "+in+" "+ format+ " "+tz.getID(), in, out);
+        } catch (final ParseException pe) {
+            if (year >= 1868 || !locale.getCountry().equals("JP")) {// LANG-978
+                throw pe;
+            }
+        }
+    }
+
     @Test
     // Check that all Locales can parse the formats we use
     public void testParses() throws Exception {
-        for(final Locale locale : Locale.getAvailableLocales()) {
-            for(final TimeZone tz : new TimeZone[]{NEW_YORK, GMT}) {
-                final Calendar cal = Calendar.getInstance(tz);
-                for(final int year : new int[]{2003, 1940, 1868, 1867, 0, -1940}) {
-                    // http://docs.oracle.com/javase/6/docs/technotes/guides/intl/calendar.doc.html
-                    if (year < 1868 && locale.equals(FastDateParser.JAPANESE_IMPERIAL)) {
-                        continue; // Japanese imperial calendar does not support eras before 1868
-                    }
-                    cal.clear();
-                    if (year < 0) {
-                        cal.set(-year, 1, 10);
-                        cal.set(Calendar.ERA, GregorianCalendar.BC);
-                    } else {
-                        cal.set(year, 1, 10);
-                    }
-                    final Date in = cal.getTime();
-                    for(final String format : new String[]{LONG_FORMAT, SHORT_FORMAT}) {
-                        final SimpleDateFormat sdf = new SimpleDateFormat(format, locale);
-                        if (format.equals(SHORT_FORMAT)) {
-                            if (year < 1930) {
-                                sdf.set2DigitYearStart(cal.getTime());
-                            }
-                        }
-                        final String fmt = sdf.format(in);
-                        try {
-                            final Date out = sdf.parse(fmt);
+        for(final String format : new String[]{LONG_FORMAT, SHORT_FORMAT}) {
+            for(final Locale locale : Locale.getAvailableLocales()) {
+                for(final TimeZone tz :  new TimeZone[]{NEW_YORK, REYKJAVIK, GMT}) {
+                     for(final int year : new int[]{2003, 1940, 1868, 1867, 1, -1, -1940}) {
+                        final Calendar cal= getEraStart(year, tz, locale);
+                        final Date centuryStart= cal.getTime();
 
-                            assertEquals(locale.toString()+" "+year+" "+ format+ " "+tz.getID(), in, out);
-                        } catch (final ParseException pe) {
-                            System.out.println(fmt+" "+locale.toString()+" "+year+" "+ format+ " "+tz.getID());
-                            throw pe;
-                        }
+                        cal.set(Calendar.MONTH, 1);
+                        cal.set(Calendar.DAY_OF_MONTH, 10);
+                        final Date in= cal.getTime();
+
+                        final FastDateParser fdp= new FastDateParser(format, tz, locale, centuryStart);
+                        validateSdfFormatFdpParseEquality(format, locale, tz, fdp, in, year, centuryStart);
                     }
                 }
             }
         }
     }
 
+    // we cannot use historic dates to test timezone parsing, some timezones have second offsets
+    // as well as hours and minutes which makes the z formats a low fidelity round trip
+    @Test
+    public void testTzParses() throws Exception {
+        // Check that all Locales can parse the time formats we use
+        for(final Locale locale : Locale.getAvailableLocales()) {
+            final FastDateParser fdp= new FastDateParser("yyyy/MM/dd z", TimeZone.getDefault(), locale);
+
+            for(final TimeZone tz :  new TimeZone[]{NEW_YORK, REYKJAVIK, GMT}) {
+                final Calendar cal= Calendar.getInstance(tz, locale);
+                cal.clear();
+                cal.set(Calendar.YEAR, 2000);
+                cal.set(Calendar.MONTH, 1);
+                cal.set(Calendar.DAY_OF_MONTH, 10);
+                final Date expected= cal.getTime();
+
+                final Date actual = fdp.parse("2000/02/10 "+tz.getDisplayName(locale));
+                Assert.assertEquals("tz:"+tz.getID()+" locale:"+locale.getDisplayName(), expected, actual);
+            }
+        }
+    }
+
+
     @Test
     public void testLocales_Long_AD() throws Exception {
         testLocales(LONG_FORMAT, false);
@@ -273,11 +323,12 @@ public class FastDateParserTest {
 
         final Calendar cal= Calendar.getInstance(GMT);
         cal.clear();
-        cal.set(2003, 1, 10);
+        cal.set(2003, Calendar.FEBRUARY, 10);
         if (eraBC) {
             cal.set(Calendar.ERA, GregorianCalendar.BC);
         }
-        for(final Locale locale : Locale.getAvailableLocales()) {
+
+        for(final Locale locale : Locale.getAvailableLocales() ) {
             // ja_JP_JP cannot handle dates before 1868 properly
             if (eraBC && locale.equals(FastDateParser.JAPANESE_IMPERIAL)) {
                 continue;
@@ -292,6 +343,28 @@ public class FastDateParserTest {
             }
         }
     }
+    
+    @Test
+    public void testJpLocales() {
+
+        final Calendar cal= Calendar.getInstance(GMT);
+        cal.clear();
+        cal.set(2003, Calendar.FEBRUARY, 10);
+        cal.set(Calendar.ERA, GregorianCalendar.BC);
+
+        final Locale locale = LocaleUtils.toLocale("zh"); {
+            // ja_JP_JP cannot handle dates before 1868 properly
+
+            final SimpleDateFormat sdf = new SimpleDateFormat(LONG_FORMAT, locale);
+            final DateParser fdf = getInstance(LONG_FORMAT, locale);
+
+            try {
+                checkParse(locale, cal, sdf, fdf);
+            } catch(final ParseException ex) {
+                Assert.fail("Locale "+locale+ " failed with "+LONG_FORMAT+"\n" + trimMessage(ex.toString()));
+            }
+        }
+    }
 
     private String trimMessage(final String msg) {
         if (msg.length() < 100) {
@@ -306,17 +379,22 @@ public class FastDateParserTest {
 
     private void checkParse(final Locale locale, final Calendar cal, final SimpleDateFormat sdf, final DateParser fdf) throws ParseException {
         final String formattedDate= sdf.format(cal.getTime());
+        checkParse(locale, sdf, fdf, formattedDate);
+        checkParse(locale, sdf, fdf, formattedDate.toLowerCase(locale));
+        checkParse(locale, sdf, fdf, formattedDate.toUpperCase(locale));
+    }
+
+    private void checkParse(final Locale locale, final SimpleDateFormat sdf, final DateParser fdf, final String formattedDate) throws ParseException {
         final Date expectedTime = sdf.parse(formattedDate);
         final Date actualTime = fdf.parse(formattedDate);
-        assertEquals(locale.toString()+" "+formattedDate
-                +"\n",expectedTime, actualTime);
+        assertEquals(locale.toString()+" "+formattedDate +"\n",expectedTime, actualTime);
     }
 
     @Test
     public void testParseNumerics() throws ParseException {
         final Calendar cal= Calendar.getInstance(NEW_YORK, Locale.US);
         cal.clear();
-        cal.set(2003, 1, 10, 15, 33, 20);
+        cal.set(2003, Calendar.FEBRUARY, 10, 15, 33, 20);
         cal.set(Calendar.MILLISECOND, 989);
 
         final DateParser fdf = getInstance("yyyyMMddHHmmssSSS", NEW_YORK, Locale.US);
@@ -327,7 +405,7 @@ public class FastDateParserTest {
     public void testQuotes() throws ParseException {
         final Calendar cal= Calendar.getInstance(NEW_YORK, Locale.US);
         cal.clear();
-        cal.set(2003, 1, 10, 15, 33, 20);
+        cal.set(2003, Calendar.FEBRUARY, 10, 15, 33, 20);
         cal.set(Calendar.MILLISECOND, 989);
 
         final DateParser fdf = getInstance("''yyyyMMdd'A''B'HHmmssSSS''", NEW_YORK, Locale.US);
@@ -343,8 +421,15 @@ public class FastDateParserTest {
         testSdfAndFdp("''yyyyMMdd'A''B'HHmmssSSS''", "'20030210A'B153320989'", false); // OK
         testSdfAndFdp("''''yyyyMMdd'A''B'HHmmssSSS''", "''20030210A'B153320989'", false); // OK
         testSdfAndFdp("'$\\Ed'" ,"$\\Ed", false); // OK
+        
+        // quoted charaters are case sensitive
+        testSdfAndFdp("'QED'", "QED", false);
+        testSdfAndFdp("'QED'", "qed", true);
+        // case sensitive after insensitive Month field
+        testSdfAndFdp("yyyy-MM-dd 'QED'", "2003-02-10 QED", false);
+        testSdfAndFdp("yyyy-MM-dd 'QED'", "2003-02-10 qed", true);
     }
-
+    
     @Test
     public void testLANG_832() throws Exception {
         testSdfAndFdp("'d'd" ,"d3", false); // OK
@@ -358,7 +443,6 @@ public class FastDateParserTest {
 
     private void testSdfAndFdp(final String format, final String date, final boolean shouldFail)
             throws Exception {
-        final boolean debug = false;
         Date dfdp = null;
         Date dsdf = null;
         Throwable f = null;
@@ -376,39 +460,30 @@ public class FastDateParserTest {
             if (!shouldFail) {
                 throw e;
             }
-            if (debug) {
-                System.out.println("sdf:"+format+"/"+date+"=>"+e);
-            }
         }
 
         try {
             final DateParser fdp = getInstance(format, NEW_YORK, Locale.US);
             dfdp = fdp.parse(date);
             if (shouldFail) {
-                Assert.fail("Expected FDF failure, but got " + dfdp + " for ["+format+","+date+"] using "+((FastDateParser)fdp).getParsePattern());
+                Assert.fail("Expected FDF failure, but got " + dfdp + " for ["+format+","+date+"]");
             }
         } catch (final Exception e) {
             f = e;
             if (!shouldFail) {
                 throw e;
             }
-            if (debug) {
-                System.out.println("fdf:"+format+"/"+date+"=>"+e);
-            }
         }
         // SDF and FDF should produce equivalent results
         assertTrue("Should both or neither throw Exceptions", (f==null)==(s==null));
         assertEquals("Parsed dates should be equal", dsdf, dfdp);
-        if (debug) {
-            System.out.println(format + "," + date + " => " + dsdf);
-        }
     }
 
     @Test
     public void testDayOf() throws ParseException {
         final Calendar cal= Calendar.getInstance(NEW_YORK, Locale.US);
         cal.clear();
-        cal.set(2003, 1, 10);
+        cal.set(2003, Calendar.FEBRUARY, 10);
 
         final DateParser fdf = getInstance("W w F D y", NEW_YORK, Locale.US);
         assertEquals(cal.getTime(), fdf.parse("3 7 2 41 03"));
@@ -416,7 +491,7 @@ public class FastDateParserTest {
 
     /**
      * Test case for {@link FastDateParser#FastDateParser(String, TimeZone, Locale)}.
-     * @throws ParseException
+     * @throws ParseException so we don't have to catch it
      */
     @Test
     public void testShortDateStyleWithLocales() throws ParseException {
@@ -424,7 +499,7 @@ public class FastDateParserTest {
         final Calendar cal = Calendar.getInstance();
         cal.clear();
 
-        cal.set(2004, 1, 3);
+        cal.set(2004, Calendar.FEBRUARY, 3);
         assertEquals(cal.getTime(), fdf.parse("2/3/04"));
 
         fdf = getDateInstance(FastDateFormat.SHORT, SWEDEN);
@@ -433,7 +508,7 @@ public class FastDateParserTest {
 
     /**
      * Tests that pre-1000AD years get padded with yyyy
-     * @throws ParseException
+     * @throws ParseException so we don't have to catch it
      */
     @Test
     public void testLowYearPadding() throws ParseException {
@@ -441,26 +516,23 @@ public class FastDateParserTest {
         final Calendar cal = Calendar.getInstance();
         cal.clear();
 
-        cal.set(1,0,1);
+        cal.set(1, Calendar.JANUARY, 1);
         assertEquals(cal.getTime(), parser.parse("0001/01/01"));
-        cal.set(10,0,1);
+        cal.set(10, Calendar.JANUARY, 1);
         assertEquals(cal.getTime(), parser.parse("0010/01/01"));
-        cal.set(100,0,1);
+        cal.set(100, Calendar.JANUARY, 1);
         assertEquals(cal.getTime(), parser.parse("0100/01/01"));
-        cal.set(999,0,1);
+        cal.set(999, Calendar.JANUARY, 1);
         assertEquals(cal.getTime(), parser.parse("0999/01/01"));
     }
 
-    /**
-     * @throws ParseException
-     */
     @Test
     public void testMilleniumBug() throws ParseException {
         final DateParser parser = getInstance(DMY_DOT);
         final Calendar cal = Calendar.getInstance();
         cal.clear();
 
-        cal.set(1000,0,1);
+        cal.set(1000, Calendar.JANUARY, 1);
         assertEquals(cal.getTime(), parser.parse("01.01.1000"));
     }
 
@@ -468,7 +540,7 @@ public class FastDateParserTest {
     public void testLang303() throws ParseException {
         DateParser parser = getInstance(YMD_SLASH);
         final Calendar cal = Calendar.getInstance();
-        cal.set(2004, 11, 31);
+        cal.set(2004, Calendar.DECEMBER, 31);
 
         final Date date = parser.parse("2004/11/31");
 
@@ -482,7 +554,7 @@ public class FastDateParserTest {
 
         final Calendar cal = Calendar.getInstance(TimeZone.getTimeZone("GMT-8"));
         cal.clear();
-        cal.set(2009, 9, 16, 8, 42, 16);
+        cal.set(2009, Calendar.OCTOBER, 16, 8, 42, 16);
 
         assertEquals(cal.getTime(), parser.parse("2009-10-16T16:42:16.000Z"));
     }
@@ -521,4 +593,128 @@ public class FastDateParserTest {
         final DateParser parser= getInstance(yMdHmsSZ, REYKJAVIK);
         assertEquals(REYKJAVIK, parser.getTimeZone());
     }
+    
+    @Test
+    public void testLang996() throws ParseException {
+        final Calendar expected = Calendar.getInstance(NEW_YORK, Locale.US);
+        expected.clear();
+        expected.set(2014, Calendar.MAY, 14);
+
+        final DateParser fdp = getInstance("ddMMMyyyy", NEW_YORK, Locale.US);        
+        assertEquals(expected.getTime(), fdp.parse("14may2014"));
+        assertEquals(expected.getTime(), fdp.parse("14MAY2014"));
+        assertEquals(expected.getTime(), fdp.parse("14May2014"));
+    }
+    
+    @Test(expected = IllegalArgumentException.class)
+    public void test1806Argument() {
+        getInstance("XXXX");
+    }
+
+    private static Calendar initializeCalendar(TimeZone tz) {
+        Calendar cal = Calendar.getInstance(tz);
+        cal.set(Calendar.YEAR, 2001);
+        cal.set(Calendar.MONTH, 1); // not daylight savings
+        cal.set(Calendar.DAY_OF_MONTH, 4);
+        cal.set(Calendar.HOUR_OF_DAY, 12);
+        cal.set(Calendar.MINUTE, 8);
+        cal.set(Calendar.SECOND, 56);
+        cal.set(Calendar.MILLISECOND, 235);
+        return cal;
+    }
+
+    private static enum Expected1806 {
+        India(INDIA, "+05", "+0530", "+05:30", true), 
+        Greenwich(GMT, "Z", "Z", "Z", false), 
+        NewYork(NEW_YORK, "-05", "-0500", "-05:00", false);
+
+        private Expected1806(TimeZone zone, String one, String two, String three, boolean hasHalfHourOffset) {
+            this.zone = zone;
+            this.one = one;
+            this.two = two;
+            this.three = three;
+            this.offset = hasHalfHourOffset ?30*60*1000 :0;
+        }
+
+        final TimeZone zone;
+        final String one;
+        final String two;
+        final String three;
+        final long offset;
+    }
+    
+    @Test
+    public void test1806() throws ParseException {
+        String formatStub = "yyyy-MM-dd'T'HH:mm:ss.SSS";
+        String dateStub = "2001-02-04T12:08:56.235";
+        
+        for (Expected1806 trial : Expected1806.values()) {
+            Calendar cal = initializeCalendar(trial.zone);
+
+            String message = trial.zone.getDisplayName()+";";
+            
+            DateParser parser = getInstance(formatStub+"X", trial.zone);
+            assertEquals(message+trial.one, cal.getTime().getTime(), parser.parse(dateStub+trial.one).getTime()-trial.offset);
+
+            parser = getInstance(formatStub+"XX", trial.zone);
+            assertEquals(message+trial.two, cal.getTime(), parser.parse(dateStub+trial.two));
+
+            parser = getInstance(formatStub+"XXX", trial.zone);
+            assertEquals(message+trial.three, cal.getTime(), parser.parse(dateStub+trial.three));
+        }
+    }
+
+    @Test
+    public void testLang1121() throws ParseException {
+        TimeZone kst = TimeZone.getTimeZone("KST");
+        final DateParser fdp = getInstance("yyyyMMdd", kst, Locale.KOREA);
+
+        try {
+            fdp.parse("2015");
+            Assert.fail("expected parse exception");
+        } catch (ParseException pe) {
+        }
+
+        // Wed Apr 29 00:00:00 KST 2015
+        Date actual = fdp.parse("20150429");
+        final Calendar cal = Calendar.getInstance(kst, Locale.KOREA);
+        cal.clear();
+        cal.set(2015, 3, 29);
+        Date expected = cal.getTime();
+        Assert.assertEquals(expected, actual);
+
+        SimpleDateFormat df = new SimpleDateFormat("yyyyMMdd", Locale.KOREA);
+        df.setTimeZone(kst);
+        expected = df.parse("20150429113100");
+
+        // Thu Mar 16 00:00:00 KST 81724
+        actual = fdp.parse("20150429113100");
+        Assert.assertEquals(expected, actual);
+    }
+
+    @Test
+    public void testParseOffset() throws ParseException {
+        DateParser parser = getInstance(YMD_SLASH);
+        final Date date = parser.parse("Today is 2015/07/04", new ParsePosition(9));
+
+        final Calendar cal = Calendar.getInstance();
+        cal.clear();
+        cal.set(2015, Calendar.JULY, 4);
+        Assert.assertEquals(cal.getTime(), date);
+    }
+
+    @Test
+    public void testDayNumberOfWeek() throws ParseException {
+        final DateParser parser = getInstance("u");
+        Calendar calendar = Calendar.getInstance();
+
+        calendar.setTime(parser.parse("1"));
+        Assert.assertEquals(Calendar.MONDAY, calendar.get(Calendar.DAY_OF_WEEK));
+
+        calendar.setTime(parser.parse("6"));
+        Assert.assertEquals(Calendar.SATURDAY, calendar.get(Calendar.DAY_OF_WEEK));
+
+        calendar.setTime(parser.parse("7"));
+        Assert.assertEquals(Calendar.SUNDAY, calendar.get(Calendar.DAY_OF_WEEK));
+    }
 }
